@@ -1,5 +1,5 @@
 package Yancy;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 # ABSTRACT: A simple CMS for administrating data
 
 #pod =head1 SYNOPSIS
@@ -13,6 +13,16 @@ our $VERSION = '0.001';
 #pod
 #pod =head1 DESCRIPTION
 #pod
+#pod =begin html
+#pod
+#pod <p>
+#pod   <img alt="Screenshot"
+#pod     src="https://raw.github.com/preaction/Yancy/master/eg/screenshot.png?raw=true"
+#pod     width="600px">
+#pod </p>
+#pod
+#pod =end html
+#pod
 #pod L<Yancy> is a simple content management system (CMS) for administering
 #pod content in a database. Yancy accepts a configuration file that describes
 #pod the data in the database and builds a website that lists all of the
@@ -344,7 +354,7 @@ Yancy - A simple CMS for administrating data
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -357,6 +367,12 @@ version 0.001
 
 =head1 DESCRIPTION
 
+=for html <p>
+  <img alt="Screenshot"
+    src="https://raw.github.com/preaction/Yancy/master/eg/screenshot.png?raw=true"
+    width="600px">
+</p>
+
 L<Yancy> is a simple content management system (CMS) for administering
 content in a database. Yancy accepts a configuration file that describes
 the data in the database and builds a website that lists all of the
